Learn R Programming

NeEDS4BigData (version 1.0.1)

One_million_songs: One million songs data

Description

This data set contains 1,019,318 unique users' music play counts in the Echo Nest, which is available at "http://millionsongdataset.com/tasteprofile/". As a basic step, it is interesting to predict the play counts using the song information collected in the Million Song Dataset (Bertin-Mahieux et al. (2011)). After cleaning up and feature engineering the data in total contains 205,032 observations where we consider the covariates duration, loudness, tempo, artist hotness and song hotness to model the response, the number of song counts.

Usage

One_million_songs

Arguments

Format

A data frame with 4 columns and 309,685 rows.

Counts

Number of playback counts for songs

Duration

Duration of the song

Loudness

Loudness of the song

Tempo

Tempo of the song

Artist_Hotness

A value between 0 and 1

Song_Hotness

A value between 0 and 1

References

mcfee2012millionNeEDS4BigData

ai2021optimalNeEDS4BigData

Examples

Run this code
nrow(One_million_songs)

Run the code above in your browser using DataLab