This data set contains 1,019,318 unique users' music play counts in the Echo Nest,
which is available at "http://millionsongdataset.com/tasteprofile/".
As a basic step, it is interesting to predict the play counts using the song
information collected in the Million Song Dataset (Bertin-Mahieux et al. (2011)).
After cleaning up and feature engineering the data in total contains 205,032
observations where we consider the covariates duration, loudness, tempo, artist
hotness and song hotness to model the response,
the number of song counts.